@@ -30,13 +30,16 @@ biclusterES <- function(bicres, number, plot=FALSE, ...)
     res <- bicres@info$Rowvalues[,number] %*% t(bicres@info$Colvalues[number,])
     if(plot==1)
     {
-        biclust:::heatmapBC(res, bicres, number=number, ...)
+        #biclust:::heatmapBC(res, bicres, number=number, ...)
+		heatmapBC(res, bicres, number=number, ...)
+		
     }
     else
     {
         if(plot==2)
         {
-            biclust:::drawHeatmap(res, bicres, number=number, ...)
+			#biclust:::drawHeatmap(res, bicres, number=number, ...)
+			drawHeatmap(res, bicres, number=number, ...)
         }
     }
 
